@@ -46,16 +46,10 @@ class TimeframeForm extends CompatForm
             'description' => $this->translate('A unique name of this timeframe')
         ]);
 
-        $default = new DateTime('00:00:00');
-        $start = $this->getPopulatedValue('start', $default);
-        if (! $start instanceof DateTime) {
-            $datetime = DateTime::createFromFormat(LocalDateTimeElement::FORMAT, $start);
-            if ($datetime) {
-                $start = $datetime;
-            }
-        }
-
-        $relativeStart = $this->getPopulatedValue('relative-start', $start instanceof DateTime ? 'n' : 'y');
+        $start = $this->getPopulatedValue('start', new DateTime('00:00:00'));
+        $canBeConverted = $start instanceof DateTime
+            || DateTime::createFromFormat(LocalDateTimeElement::FORMAT, $start) !== false;
+        $relativeStart = $this->getPopulatedValue('relative-start', $canBeConverted ? 'n' : 'y');
         $this->addElement('checkbox', 'relative-start', [
             'required' => false,
             'class'    => 'autosubmit',
@@ -65,7 +59,7 @@ class TimeframeForm extends CompatForm
 
         if ($relativeStart === 'n') {
             if (! $start instanceof DateTime) {
-                $start = $default;
+                $start = (new DateTime($start))->format(LocalDateTimeElement::FORMAT);
                 $this->clearPopulatedValue('start');
             }
 
@@ -101,16 +95,10 @@ class TimeframeForm extends CompatForm
             ]);
         }
 
-        $default = new DateTime('23:59:59');
-        $end = $this->getPopulatedValue('end', $default);
-        if (! $end instanceof DateTime) {
-            $datetime = DateTime::createFromFormat(LocalDateTimeElement::FORMAT, $end);
-            if ($datetime) {
-                $end = $datetime;
-            }
-        }
-
-        $relativeEnd = $this->getPopulatedValue('relative-end', $end instanceof DateTime ? 'n' : 'y');
+        $end = $this->getPopulatedValue('end', new DateTime('23:59:59'));
+        $canBeConverted = $end instanceof DateTime
+            || DateTime::createFromFormat(LocalDateTimeElement::FORMAT, $end) !== false;
+        $relativeEnd = $this->getPopulatedValue('relative-end', $canBeConverted ? 'n' : 'y');
         if ($relativeStart === 'y') {
             $this->addElement('checkbox', 'relative-end', [
                 'required' => false,
@@ -120,9 +108,34 @@ class TimeframeForm extends CompatForm
             ]);
         }
 
+        $endDateValidator = new CallbackValidator(function ($value, CallbackValidator $validator) {
+            if (! $value instanceof DateTime) {
+                try {
+                    $value = new DateTime($value);
+                } catch (Exception $_) {
+                    $validator->addMessage($this->translate('Invalid textual date time'));
+
+                    return false;
+                }
+            }
+
+            $start = $this->getValue('start');
+            if (! $start instanceof DateTime) {
+                $start = new DateTime($start);
+            }
+
+            if ($value <= $start) {
+                $validator->addMessage($this->translate('End time must be greater than start time'));
+
+                return false;
+            }
+
+            return true;
+        });
+
         if ($relativeEnd === 'n' || $relativeStart === 'n') {
             if (! $end instanceof DateTime) {
-                $end = $default;
+                $end = (new DateTime($end))->format(LocalDateTimeElement::FORMAT);
                 $this->clearPopulatedValue('end');
             }
 
@@ -131,7 +144,8 @@ class TimeframeForm extends CompatForm
                     'required'    => true,
                     'value'       => $end,
                     'label'       => $this->translate('End'),
-                    'description' => $this->translate('Specifies the end time of this timeframe')
+                    'description' => $this->translate('Specifies the end time of this timeframe'),
+                    'validators'  => [$endDateValidator]
                 ])
             );
         } else {
@@ -140,21 +154,7 @@ class TimeframeForm extends CompatForm
                 'label'       => $this->translate('End'),
                 'placeholder' => $this->translate('Last day of this month'),
                 'description' => $this->translate('Specifies the end time of this timeframe'),
-                'validators' => [
-                    new CallbackValidator(function ($value, CallbackValidator $validator) {
-                        if ($value !== null) {
-                            try {
-                                new DateTime($value);
-                            } catch (Exception $_) {
-                                $validator->addMessage($this->translate('Invalid textual date time'));
-
-                                return false;
-                            }
-                        }
-
-                        return true;
-                    })
-                ]
+                'validators' => [$endDateValidator]
             ]);
         }
 
